@@ -31,6 +31,39 @@
 
 # Some of these functions have been borrowed from the RGCCA package, as indicated below
 
+# --------------------------------------
+# study_split: used in 'internal_mint.block.R' and 'predict.mint.block.pls.R'
+# --------------------------------------
+get.weights = function(variates, indY)
+{
+    ncomp = min(sapply(variates, ncol))
+    x.xList <- list()
+    compt = 1
+    for(comp in 1:ncomp)
+    {
+        for(i in 1:length(variates)){
+            corDat <- rep(0, length(variates))
+            names(corDat) <- paste("cor", names(variates)[i], names(variates), sep = "_")
+            for(j in 1:length(variates)){
+                corDat[j] <- as.numeric(cor(variates[[i]][,comp], variates[[j]][,comp]))
+            }
+            x.xList[[compt]] <- corDat
+            compt = compt +1
+        }
+    }
+    corMat.diablo <- do.call(rbind, x.xList)
+    rownames(corMat.diablo) <- paste(names(variates),".comp",rep(1:ncomp,each=length(variates)),sep="")
+    colnames(corMat.diablo) <- names(variates)
+    
+    temp = matrix(corMat.diablo[,indY],ncol=ncomp)
+    correlation = apply(temp, 1, function(x){mean(abs(x))})[1:length(variates)]
+    names(correlation) = names(variates)
+    
+    correlation = correlation[-indY]
+    return(correlation)
+    
+}
+
 
 # --------------------------------------
 # study_split: used in 'internal_mint.block.R' and 'predict.mint.block.pls.R'
