@@ -63,7 +63,8 @@ xlim  = NULL,
 ylim  = NULL, 
 col, 
 cex, 
-pch, 
+pch,
+pch.levels,
 alpha = 0.2, # used in shade3d
 axes.box  = "box", 
 layout = NULL, 
@@ -75,14 +76,15 @@ size.axis = rel(0.8),
 size.legend = rel(1), #size.legend
 size.legend.title = rel(1.1), #size.legend.title
 legend.title = "Legend",
-legend.position = "right", 
+legend.title.pch = "Legend",
+legend.position = "right",
 point.lwd = 1, 
 ...
 )
 {
     plot_parameters = list(size.title = size.title, size.subtitle = size.subtitle, size.xlabel = size.xlabel, size.ylabel = size.ylabel,
     size.axis = size.axis, size.legend = size.legend, size.legend.title = size.legend.title, legend.title = legend.title,
-    legend.position = legend.position, point.lwd = point.lwd)
+    legend.title.pch = legend.title.pch, legend.position = legend.position, point.lwd = point.lwd)
 
     if (any(class(object)%in%c("mint.block.pls", "mint.block.spls", "mint.block.plsda", "mint.block.splsda")))
     stop("No plotIndiv for the following functions at this stage: mint.block.pls, mint.block.spls, mint.block.plsda, mint.block.splsda.")
@@ -162,7 +164,7 @@ point.lwd = 1,
     out = shape.input.plotIndiv(object = object, n = n, blocks  = blocks, x = x, y = y, z = z, ind.names  = ind.names, group = group,
     col.per.group = col.per.group, style = style, study = "global", ellipse  = ellipse, ellipse.level  = ellipse.level,
     centroid = centroid, star = star, title = title, xlim  = xlim, ylim  = ylim, 
-    col = col, cex = cex, pch = pch, display.names = display.names, plot_parameters = plot_parameters)
+    col = col, cex = cex, pch = pch, pch.levels = pch.levels, display.names = display.names, plot_parameters = plot_parameters)
     #-- retrieve outputs
     df = out$df
     df.ellipse = out$df.ellipse
@@ -171,14 +173,14 @@ point.lwd = 1,
     display.names = out$display.names
     xlim = out$xlim
     ylim = out$ylim
-    missing.col = out$missing.col
+    #missing.col = out$missing.col
     ellipse = out$ellipse
     centroid = out$centroid
     star = out$star
     plot_parameters = out$plot_parameters
 
     # change the levels of df$Block to "subtitle"
-    if (!missing(subtitle) & !is.null(title))
+    if (!missing(subtitle) & nlevels(df$Block)>1)#& !is.null(title)) # commented so that subtitle can be change without changing the title
     {
         df$Block = factor(df$Block, labels = subtitle)
         if (ellipse)
@@ -190,7 +192,7 @@ point.lwd = 1,
     res = internal_graphicModule(df = df, centroid = centroid, col.per.group = col.per.group, title = title,
     X.label = X.label, Y.label = Y.label, Z.label = Z.label, xlim = xlim, ylim = ylim, class.object = class(object),
     display.names = display.names, legend = legend, abline = abline, star = star,
-    ellipse = ellipse, df.ellipse = df.ellipse, style = style, layout = layout, missing.col = missing.col,
+    ellipse = ellipse, df.ellipse = df.ellipse, style = style, layout = layout, #missing.col = missing.col,
     axes.box = axes.box, plot_parameters = plot_parameters, alpha = alpha)
 
 
