@@ -1,13 +1,16 @@
-# Copyright (C) 2009 
-# Fangzhou Yao, Queensland Facility for Advanced Bioinformatics, University of Queensland, Australia and
-# Shangai University of Finance and Economics, Shanghai, P.R. China
-# Jeff Coquery, Queensland Facility for Advanced Bioinformatics, University of Queensland, Australia and
-# Sup Biotech, Paris, France
-# Ignacio Gonzalez, Genopole Toulouse Midi-Pyrenees, France
-# Francois Bartolo, Institut National des Sciences Appliquees et Institut de Mathematiques, Universite de Toulouse et CNRS (UMR 5219), France
-# Kim-Anh Le Cao, French National Institute for Agricultural Research and 
-# Queensland Facility for Bioinformatics, University of Queensland, Australia
-
+# Authors:
+#
+# The function ica.par and ica.def are borrowed from the fastICA package (see references).
+#
+#   Fangzhou Yao, Queensland Facility for Advanced Bioinformatics, University of Queensland, Australia and Shangai University of Finance and Economics, Shanghai, P.R. China
+#   Jeff Coquery, Queensland Facility for Advanced Bioinformatics, University of Queensland, Australia and Sup Biotech, Paris, France
+#   Francois Bartolo, Institut National des Sciences Appliquees et Institut de Mathematiques, Universite de Toulouse et CNRS (UMR 5219), France
+#   Kim-Anh Le Cao, French National Institute for Agricultural Research and Queensland Facility for Bioinformatics, University of Queensland, Australia
+#
+# created: 2011
+# last modified: 17-03-2016
+#
+# Copyright (C) 2011
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,8 +25,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-#
-# The function ica.par and ica.def are borrowed from the fastICA package (see references).
 
 
 sipca <-
@@ -121,13 +122,20 @@ function (X, ncomp  = 3, mode = c("deflation","parallel"),
         cl = match.call()
 		cl[[1]] = as.name('sipca')
 
-        result = (list(call=cl, X = X, ncomp=ncomp, keepX=keepX, unmixing = t(unmix_mat), mixing = t(mix_mat), loadings = list(t(independent_mat.new)), rotation = t(independent_mat.new),
-        kurtosis = kurt[order(kurt,decreasing=TRUE)],names = list(X = X.names, indiv = ind.names)))
+        result = (list(call=cl, X = X, ncomp=ncomp, keepX=keepX, unmixing = t(unmix_mat), mixing = t(mix_mat), loadings = list(X=t(independent_mat.new)), rotation = t(independent_mat.new),
+        kurtosis = kurt[order(kurt,decreasing=TRUE)],names = list(X = X.names, sample = ind.names)))
 		
 		result$x = ipc_mat
-        result$variates=list(ipc_mat)
+        result$variates=list(X=ipc_mat)
         dimnames(result$x) = list(ind.names, paste("IPC", 1:ncol(result$rotation), sep = " "))
 		
-		class(result) = c("sipca")
+		class(result) = c("sipca","ipca","pca")
+               
+        #calcul explained variance
+        explX=explained_variance(X,result$variates$X,ncomp)
+        result$explained_variance=explX
+    
+    
+        
 		return(invisible(result))
     } 
